@@ -4,6 +4,7 @@ import argparse
 import logging
 import os
 import sys
+import time
 
 import log
 
@@ -80,7 +81,7 @@ def configure_logging(count=0):
 
     # Set a custom formatter
     log.init(level=level)
-    log.silence('yorm', allow_warning=True)
+    log.silence('datafiles', allow_warning=True)
     logging.captureWarnings(True)
     formatter = WarningFormatter(
         default_format, verbose_format, datefmt=settings.LOGGING_DATEFMT
@@ -126,6 +127,9 @@ def show(
 
     color = kwargs.pop('color', None)
 
+    if color == 'message':
+        time.sleep(settings.RECORDING_DELAY)
+
     for message in messages:
         if _Config.verbosity == 0:
             text = ' ' * 2 * _Config.indent_level + style(message, color)
@@ -138,6 +142,9 @@ def show(
                 else:
                     log.info(message)
 
+    if color == 'message':
+        time.sleep(settings.RECORDING_DELAY)
+
 
 BOLD = '\033[1m'
 RED = '\033[31m'
@@ -155,7 +162,7 @@ COLORS = dict(
     git_dirty=BOLD + MAGENTA,
     git_changes=YELLOW,
     shell=BOLD + GREEN,
-    shell_info=BOLD + MAGENTA,
+    shell_info=MAGENTA,
     shell_output=CYAN,
     shell_error=YELLOW,
     message=BOLD + WHITE,
